@@ -28,6 +28,7 @@ use Carp qw(croak);
 use Cwd qw(abs_path);
 use Errno qw(ENOENT);
 use Exporter qw(import);
+use Path::Tiny;
 use POSIX qw(sigprocmask SIG_BLOCK SIG_UNBLOCK SIG_SETMASK);
 use YAML::XS ();
 
@@ -64,7 +65,6 @@ BEGIN {
           get_dsc_info
           get_file_checksum
           get_file_digest
-          slurp_entire_file
           file_is_encoded_in_non_utf8
           is_string_utf8_encoded
           fail
@@ -75,11 +75,9 @@ BEGIN {
           lstrip
           rstrip
           system_env
-          delete_dir
           copy_dir
           gunzip_file
           open_gz
-          touch_file
           perm2oct
           check_path
           clean_env
@@ -119,12 +117,7 @@ Lintian::Util - Lintian utility functions
 
 =head1 SYNOPSIS
 
- use Lintian::Util qw(slurp_entire_file normalize_pkg_path);
- 
- my $text = slurp_entire_file('some-file');
- if ($text =~ m/regex/) {
-    # ...
- }
+ use Lintian::Util qw(normalize_pkg_path);
 
  my $path = normalize_pkg_path('usr/bin/', '../lib/git-core/git-pull');
  if (defined $path) {
@@ -745,31 +738,6 @@ sub get_dsc_info {
     return (defined($data[0])? $data[0] : undef);
 }
 
-=item slurp_entire_file (FOH[, NOCLOSE])
-
-Reads the contents of FOH into memory and return it as a scalar.  FOH
-can be either the path to a file or an open file handle.
-
-If it is a handle, the optional NOCLOSE parameter can be used to
-prevent the sub from closing the handle.  The NOCLOSE parameter has no
-effect if FOH is not a handle.
-
-=cut
-
-sub slurp_entire_file {
-    my ($file, $noclose) = @_;
-    my $fd;
-    if (openhandle($file)) {
-        $fd = $file;
-    } else {
-        open($fd, '<', $file);
-    }
-    local $/;
-    local $_ = <$fd>;
-    close($fd) unless $noclose && openhandle($file);
-    return $_;
-}
-
 =item drain_pipe(FD)
 
 Reads and discards any remaining contents from FD, which is assumed to
@@ -1122,16 +1090,6 @@ sub run_cmd {
     return 1;
 }
 
-=item delete_dir (ARGS)
-
-Convenient way of calling I<rm -fr ARGS>.
-
-=cut
-
-sub delete_dir {
-    return run_cmd('rm', '-rf', '--', @_);
-}
-
 =item copy_dir (ARGS)
 
 Convenient way of calling I<cp -a ARGS>.
@@ -1184,29 +1142,6 @@ sub __open_gz_ext {
     return $fd;
 }
 
-=item touch_file(FILE)
-
-Updates the "mtime" of FILE.  If FILE does not exist, it will be
-created.
-
-On failure, this sub will emit a trappable error.
-
-=cut
-
-sub touch_file {
-    my ($file) = @_;
-
-    # We use '>>' because '>' truncates the file if it has contents
-    # (which `touch file` doesn't).
-    open(my $fd, '>>', $file);
-    # open with '>>' does not update the mtime if the file already
-    # exists, so use utime to solve that.
-    utime(undef, undef, $fd);
-    close($fd);
-
-    return 1;
-}
-
 =item internal_error (MSG[, ...])
 
 Use to signal an internal error. The argument(s) will used to print a
@@ -1661,17 +1596,13 @@ sub load_state_cache {
     my ($state_dir) = @_;
     my $state_file = "$state_dir/state-cache";
     my $state = {};
-    my $fd;
-    eval {open($fd, '<:raw', $state_file);};
-    if (my $err = $@) {
-        if ($err->errno != ENOENT) {
-            # Present, but unreadable for some reason
-            die($err);
-        }
-        # Not present; presume empty
-        return $state;
-    }
-    eval {$state = YAML::XS::Load(slurp_entire_file($fd, 1));};
+
+    return $state
+      unless -f $state_file;
+
+    my $yaml = path($state_file)->slurp;
+
+    eval {$state = YAML::XS::Load($yaml);};
     # Not sure what Load does in case of issues; perldoc YAML says
     # very little about it.  Based on YAML::Error, I guess it will
     # write stuff to STDERR and use die/croak, but it remains a
@@ -1684,7 +1615,6 @@ sub load_state_cache {
     if (ref($state) ne 'HASH') {
         die("$state_file was invalid; please fix or remove it.");
     }
-    close($fd);
     return $state;
 }
 
