@@ -73,7 +73,7 @@ use Test::Lintian::Helper qw(rfc822date);
 use Test::Lintian::Hooks
   qw(find_missing_prerequisites run_lintian sed_hook sort_lines calibrate);
 use Test::Lintian::Prepare qw(early_logpath);
-use Test::Lintian::UniversalTags qw(get_tagnames);
+use Test::Lintian::Output::Universal qw(get_tagnames);
 use Test::StagedFileProducer;
 
 use constant SPACE => q{ };
@@ -263,9 +263,9 @@ sub runner {
         });
 
     # run lintian
-    my $actual = "$runpath/tags.actual";
+    my $raw = "$runpath/tags.actual";
     $producer->add_stage(
-        products => [$actual],
+        products => [$raw],
         minimum_epoch => $lintian_epoch,
         build =>sub {
             $ENV{'LINTIAN_COVERAGE'}.= ",-db,./cover_db-$testcase->{testname}"
@@ -296,7 +296,7 @@ sub runner {
             # do not forget the final newline, or sorting will fail
             my $contents
               = scalar @lines ? join(NEWLINE, @lines) . NEWLINE : EMPTY;
-            path($actual)->spew($contents);
+            path($raw)->spew($contents);
         });
 
     # run a sed-script if it exists
@@ -306,10 +306,10 @@ sub runner {
         build =>sub {
             my $script = "$runpath/post_test";
             if(-f $script) {
-                sed_hook($script, $actual, $parsed);
+                sed_hook($script, $raw, $parsed);
             } else {
-                die"Could not copy actual tags $actual to $parsed: $!"
-                  if(system('cp', '-p', $actual, $parsed));
+                die"Could not copy actual tags $raw to $parsed: $!"
+                  if(system('cp', '-p', $raw, $parsed));
             }
         });
 
@@ -328,6 +328,10 @@ sub runner {
 
     my $specified = "$runpath/tags";
 
+    # create tags if there are none; helps when calibrating new tests
+    path($specified)->touch
+      unless -e $specified;
+
     # calibrate tags; may write to $sorted
     my $calibrated = "$runpath/tags.specified.calibrated";
     $producer->add_stage(
@@ -343,7 +347,7 @@ sub runner {
         });
 
     # extract expected tags
-    my $expected = "$runpath/tags.specified.calibrated.extracted";
+    my $expected = "$runpath/tags.specified.calibrated.universal";
     $producer->add_stage(
         products => [$expected],
         build =>sub {
@@ -353,14 +357,12 @@ sub runner {
         });
 
     # extract actual tags
-    my $extracted = "$runpath/tags.actual.parsed.sorted.extracted";
+    my $actual = "$runpath/tags.actual.parsed.sorted.universal";
     $producer->add_stage(
-        products => [$extracted],
+        products => [$actual],
         build =>sub {
-            my @command = (
-                'tagextract', '-f', $testcase->{output_format},
-                $sorted, $extracted
-            );
+            my @command = ('tagextract', '-f', $testcase->{output_format},
+                $sorted, $actual);
             die 'Error executing: ' . join(SPACE, @command) . ": $!"
               if system(@command);
         });
@@ -368,9 +370,9 @@ sub runner {
     say EMPTY;
     $producer->run(verbose => 1);
 
-    my @errors = check_result($testcase, $extracted, $expected);
+    my @errors = check_result($testcase, $expected, $actual);
 
-    my $okay = !scalar @errors;
+    my $okay = !(scalar @errors);
 
     if($testcase->{todo} eq 'yes') {
       TODO: {
@@ -389,15 +391,16 @@ sub runner {
     #      unless -e "$runpath/test_calibration";
 
     unless($okay) {
-        my @command = ('tagdiff', $expected, $extracted);
+        my @command = ('tagdiff', $expected, $actual);
         my ($diff, $status) = capture_merged { system(@command); };
         $status = ($status >> 8) & 255;
         die 'Error executing: ' . join(SPACE, @command) . ": $!"
           if $status;
 
         if (length $diff) {
+            path("$runpath/tagdiff")->spew_utf8($diff);
             diag '--- ' . abs2rel($expected);
-            diag '+++ ' . abs2rel($extracted);
+            diag '+++ ' . abs2rel($actual);
             diag $diff;
         }
     }
@@ -405,7 +408,7 @@ sub runner {
     return;
 }
 
-=item check_result(DESC, ACTUAL, EXPECTED, ORIGINAL)
+=item check_result(DESC, EXPECTED, ACTUAL)
 
 This routine checks if the EXPECTED tags match the calibrated ACTUAL for the
 test described by DESC. For some additional checks, also need the ORIGINAL
@@ -414,10 +417,10 @@ tags before calibration. Returns a list of errors, if there are any.
 =cut
 
 sub check_result {
-    my ($testcase, $actualpath, $expectedpath) = @_;
+    my ($testcase, $expectedpath, $actualpath) = @_;
 
     # fail if tags do not match
-    return 'Tags do not match' if (compare($actualpath, $expectedpath) != 0);
+    return 'Tags do not match' if (compare($expectedpath, $actualpath) != 0);
 
     # no furter checks if the test is not about tags
     return unless length $testcase->{check};
@@ -454,20 +457,6 @@ sub check_result {
     #diag "+Test-For: $_" for @test_for;
     #diag "-Test-Against (calculated): $_" for @test_against;
 
-    # get Test-Against if present, and override
-    if (exists $testcase->{test_against}) {
-        my @override = sort +split(SPACE, $testcase->{test_against});
-
-        #diag "&Test-Against (override): $_" for @override;
-
-        diag
-"$testcase->{testname}: Explicit Test-Against matches computed value."
-          if List::Compare->new(\@test_against, \@override)->is_LequivalentR();
-
-        # override
-        @test_against = @override;
-    }
-
     # get actual tags from output
     my @actual = sort +get_tagnames($actualpath);
 
@@ -486,10 +475,6 @@ sub check_result {
     # warn about missing tags
     push(@errors, "Tag $_ listed in Test-For but not seen")for @missing;
 
-    push(@errors,
-'Test-Against is empty (requiring tags in Test-For) but no tags are expected'
-    )unless scalar @test_against || scalar @test_for;
-
     return @errors;
 }
 
